caellion-python-commons: caellion.pycommons.serializers.datetime_serializer.DateTimeIsoTimeSerializer Class Reference

caellion-python-commons

Static Public Member Functions | List of all members
caellion.pycommons.serializers.datetime_serializer.DateTimeIsoTimeSerializer Class Reference

Implementation of DateTime serializer, using IsoTime as a serialized standard. More...

## Static Public Member Functions
def | deserialize (serialized_string)
| Unserializes the ISO string to DateTime object. More...
def | unserialize (serialized_string)
| Unserializes the ISO string to DateTime object. More...
def | serialize (datetime_to_serialize)
| Serializes the DateTime to ISO string. More...

## Detailed Description

Implementation of DateTime serializer, using IsoTime as a serialized standard.

Definition at line 9 of file datetime_serializer.py.

## Member Function Documentation

## ◆ deserialize()

def caellion.pycommons.serializers.datetime_serializer.DateTimeIsoTimeSerializer.deserialize | ( |  | serialized_string | ) |
| static

Unserializes the ISO string to DateTime object.

Always returns UTC timezone DateTime.

Alias for unserialize()

Parameters

  serialized_string | serialized datetime to unserialize

Returns
  DateTime with UTC timezone

Definition at line 16 of file datetime_serializer.py.

## ◆ serialize()

def caellion.pycommons.serializers.datetime_serializer.DateTimeIsoTimeSerializer.serialize | ( |  | datetime_to_serialize | ) |
| static

Serializes the DateTime to ISO string.

Always returns UTC timezone string.

Parameters

  datetime_to_serialize | DateTime to serialize to UTC timezoned ISO string

Returns
  ISO String

Definition at line 40 of file datetime_serializer.py.

## ◆ unserialize()

def caellion.pycommons.serializers.datetime_serializer.DateTimeIsoTimeSerializer.unserialize | ( |  | serialized_string | ) |
| static

Unserializes the ISO string to DateTime object.

Always returns UTC timezone DateTime.

Parameters

  serialized_string | serialized datetime to unserialize

Returns
  DateTime with UTC timezone

Definition at line 29 of file datetime_serializer.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/serializers/datetime_serializer.py